@@ -13,6 +13,7 @@ from django.test import (
     modify_settings,
     override_settings,
 )
+from django.utils.deprecation import RemovedInDjango61Warning
 
 
 @override_settings(ROOT_URLCONF="auth_tests.urls")
@@ -487,3 +488,51 @@ class PersistentRemoteUserTest(RemoteUserTest):
         response = await self.async_client.get("/remote_user/")
         self.assertFalse(response.context["user"].is_anonymous)
         self.assertEqual(response.context["user"].username, "knownuser")
+
+
+# RemovedInDjango61Warning.
+class CustomProcessRequestMiddlewareSyncOnly(RemoteUserMiddleware):
+    def process_request(self, request):
+        raise NotImplementedError("process_request has not been implemented.")
+
+
+# RemovedInDjango61Warning.
+class CustomProcessRequestMiddleware(RemoteUserMiddleware):
+    def process_request(self, request):
+        raise NotImplementedError("process_request has not been implemented.")
+
+    async def aprocess_request(self, request):
+        raise NotImplementedError("aprocess_request has not been implemented.")
+
+
+# RemovedInDjango61Warning.
+@override_settings(ROOT_URLCONF="auth_tests.urls")
+class CustomProcessRequestMiddlewareTest(TestCase):
+    @modify_settings(
+        MIDDLEWARE={
+            "append": "auth_tests.test_remote_user."
+            "CustomProcessRequestMiddlewareSyncOnly"
+        }
+    )
+    async def test_async_warns_sync_only_middleware(self):
+        deprecation_msg = (
+            "Support for subclasses of RemoteUserMiddleware that override "
+            "process_request() without overriding aprocess_request() is "
+            "deprecated."
+        )
+        error_msg = "process_request has not been implemented."
+        with (
+            self.assertWarnsMessage(RemovedInDjango61Warning, deprecation_msg),
+            self.assertRaisesMessage(NotImplementedError, error_msg),
+        ):
+            await self.async_client.get("/remote_user/")
+
+    @modify_settings(
+        MIDDLEWARE={
+            "append": "auth_tests.test_remote_user.CustomProcessRequestMiddleware"
+        }
+    )
+    async def test_async_no_warning_sync_and_async_middleware(self):
+        error_msg = "aprocess_request has not been implemented."
+        with self.assertRaisesMessage(NotImplementedError, error_msg):
+            await self.async_client.get("/remote_user/")
