@@ -1,3 +1,6 @@
+from unittest.mock import patch
+
+from django.db import connection
 from django.db.models import (
     Case,
     F,
@@ -6,6 +9,7 @@ from django.db.models import (
     Q,
     Subquery,
     TextField,
+    Value,
     When,
 )
 from django.db.models.functions import Cast
@@ -206,6 +210,14 @@ class CompositePKFilterTests(TestCase):
             [self.comment_1],
         )
 
+    def test_filter_by_pk_in_subquery_invalid_selected_columns(self):
+        msg = (
+            "The QuerySet value for the 'in' lookup must have 2 selected "
+            "fields (received 3)"
+        )
+        with self.assertRaisesMessage(ValueError, msg):
+            Comment.objects.filter(pk__in=Comment.objects.values("pk", "text"))
+
     def test_filter_by_pk_in_none(self):
         with self.assertNumQueries(0):
             self.assertSequenceEqual(
@@ -238,6 +250,10 @@ class CompositePKFilterTests(TestCase):
             Comment.objects.filter(user=self.user_1).contains(self.comment_1), True
         )
 
+    def test_filter_query_does_not_mutate(self):
+        queryset = User.objects.filter(comments__in=Comment.objects.all())
+        self.assertEqual(str(queryset.query), str(queryset.query))
+
     def test_filter_users_by_comments_in(self):
         c1, c2, c3, c4, c5 = (
             self.comment_1,
@@ -533,3 +549,19 @@ class CompositePKFilterTests(TestCase):
                 ).filter(filtered_tokens=(1, 1)),
                 [self.tenant_1],
             )
+
+    def test_filter_by_tuple_containing_expression(self):
+        pk_lookup = (self.comment_1.tenant.id, (Value(self.comment_1.id) + 1) - 1)
+        for lookup in ({"pk": pk_lookup}, {"pk__in": [pk_lookup]}):
+            with self.subTest(lookup=lookup):
+                qs = Comment.objects.filter(**lookup)
+                self.assertEqual(qs.get(), self.comment_1)
+
+
+@skipUnlessDBFeature("supports_tuple_lookups")
+class CompositePKFilterTupleLookupFallbackTests(CompositePKFilterTests):
+    def setUp(self):
+        feature_patch = patch.object(
+            connection.features, "supports_tuple_lookups", False
+        )
+        self.enterContext(feature_patch)
